#ifndef __CBRC_H_
#define __CBRC_H_

/** \file cbrc.h
  * \brief Constants for resources defined in cb.rc.
  */

/** \brief ID of the icon to use for the application.
  */
#define MAINICON                    101

/** \brief String "Really quit?"
  */
#define S_QUIT                      201
/** \brief Error string printed, if opening the GPS port failed.
  */
#define S_OPENERR                   202
/** \brief Error string printed, if closing the GPS port failed.
  */
#define S_CLOSEERR                  203
/** \brief Format string for the UTC time shown in the main window.
  */
#define S_UTCFMT                    204
/** \brief Format string for the positive latitude shown in the main window.
  */
#define S_NLATFMT                   205
/** \brief Format string for the negative latitude shown in the main window.
  */
#define S_SLATFMT                   206
/** \brief Format string for the positive longitude shown in the main window.
  */
#define S_ELONFMT                   207
/** \brief Format string for the negative longitude shown in the main window.
  */
#define S_WLONFMT                   208
/** \brief Format of the altitude shown in the main window.
  */
#define S_ALTFMT                    209
/** \brief Format of the UTM easting shown in the main window.
  */
#define S_UTMEFMT                   210
/** \brief Format of the UTM northing shown in the main window.
  */
#define S_UTMNFMT                   211
/** \brief Filter string for the openfilename structure for GPX files.
  */
#define S_GPXFILTER                 212
/** \brief Readonly text box for the UTC time in the main window
  */
#define T_UTC                       301
/** \brief Readonly text box for the altitude in the main window
  */
#define T_ALT                       302
/** \brief Readonly text box for the latitude in the main window
  */
#define T_LAT                       303
/** \brief Readonly text box for the longitude in the main window
  */
#define T_LON                       304
/** \brief Readonly text box for UTM northing in the main window
  */
#define T_UTMN                      305
/** \brief Readonly text box for UTM easting in the main window
  */
#define T_UTME                      306

/** \brief Combo box for selecting serial port in the configuration window.
  */
#define CB_PORT                     407
/** \brief Combo box for selecting baud rate in the configuration window.
  */
#define CB_SPEED                    408
/** \brief Combo box for selecting number of databits in the configuration
  *        window.
  */
#define CB_DATABITS                 409
/** \brief Combo box for selecting parity in the configuration window.
  */
#define CB_PARITY                   410
/** \brief Combo box for selecting number of stopbits in the configuration
  *        window.
  */
#define CB_STOPBITS                 411
/** \brief ID of the dialog template for the main window.
  */
#define DLG_CB                      501
/** \brief ID of the configuration dialog template.
  */
#define DLG_CBCFG                   502

/** \brief Main menu.
  */
#define M_MAIN                      602
/** \brief Menu item "start".
  */
#define M_START                     603
/** \brief Menu item "stop".
  */
#define M_STOP                      604
/** \brief Menu item "config".
  */
#define M_CFG                       605
#ifdef UNDER_CE
/** \brief Menu item "display off".
  */
#define M_DOFF                      606
#endif
/** \brief Menu item "start gpx".
  */
#define M_GPXSTART                  607
/** \brief Menu item "stop gpx".
  */
#define M_GPXSTOP                   608
/** \brief Menu item "exit".
  */
#define M_EXIT                      610

#ifndef RCREVISION
# define RCREVISION 0,0,0,0
#endif

#ifndef RCREVTXT
# define RCREVTXT "0,0,0,0\0"
#endif

#endif

