#include "cbthr.h"

const t_cbthr CBINVALIDTHREAD = (t_cbthr) NULL;

int cbthr_create(t_cbthr     *theThread,
                 t_cbthrfunc aThrFunc,
                 void        *thrFuncParms) {
  int retval;

  retval = 0;
  if (theThread != NULL && aThrFunc != NULL) {
#ifdef W32_THREADS
    *theThread = CreateThread(NULL,
                              0,
                              aThrFunc,
                              thrFuncParms,
                              0,
                              NULL);
    if (*theThread != 0) retval = 1; 
#else
    if (pthread_create(theThread, NULL, aThrFunc, thrFuncParms) == 0)
      retval = 1;
#endif
  }
  return retval;
} /* cbthr_create() */

int cbthr_join(t_cbthr aThread) {
#ifdef W32_THREADS
  if (WaitForSingleObject(aThread, INFINITE) == WAIT_FAILED) return 1;
  CloseHandle(aThread);
  return 0;
#else
  return pthread_join(aThread, NULL);
#endif
} /* cbthr_join() */

int cbthr_init_cs(t_cbthrcs *aCritSec) {
  int retval;

  retval = -1;
  if (aCritSec != NULL) {
#ifdef W32_THREADS
    InitializeCriticalSection(aCritSec);
    retval = 0;
#else
    retval = pthread_mutex_init(aCritSec, NULL);
#endif
  }
  return retval;
} /* cbthr_init_cs() */

int cbthr_enter_cs(t_cbthrcs *aCritSec) {
  int retval;

  retval = -1;
  if (aCritSec != NULL) {
#ifdef W32_THREADS
    EnterCriticalSection(aCritSec);
    retval = 0;
#else
    retval = pthread_mutex_lock(aCritSec);
#endif
  }
  return retval;
} /* cbthr_enter_cs() */

int cbthr_leave_cs(t_cbthrcs *aCritSec) {
  int retval;

  retval = -1;
  if (aCritSec != NULL) {
#ifdef W32_THREADS
    LeaveCriticalSection(aCritSec);
    retval = 0;
#else
    retval = pthread_mutex_unlock(aCritSec);
#endif
  }
  return retval;
} /* cbthr_leave_cs() */

int cbthr_delete_cs(t_cbthrcs *aCritSec) {
  int retval;

  retval = -1;
  if (aCritSec != NULL) {
#ifdef W32_THREADS
    DeleteCriticalSection(aCritSec);
    retval = 0;
#else
    retval = pthread_mutex_destroy(aCritSec);
#endif
  }
  return retval;
} /* cbthr_delete_cs() */

